use strict;
use Test::More tests => 8;
use Data::Dumper;
BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  true;
  false;
  
  var a = true;
  var b = false;
  
  var c = true == false;
};

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree,undef,'Got a parse')
  or diag Dumper($tree);

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//Boolean');
is(scalar @nodes, 6, "6 boolean literals found")
  or do { diag $_->toString for @nodes };

@nodes = $tree->findnodes('//VariableDeclaration[./Identifier/text() = "a" and ./Initializer//Boolean/text() = "1"]');
is(scalar @nodes, 1, "a is assigned true")
  or do { diag $_->toString for @nodes };

@nodes = $tree->findnodes('//VariableDeclaration[./Identifier/text() = "b" and ./Initializer//Boolean/text() = "0"]');
is(scalar @nodes, 1, "b is assigned false")
  or do { diag $_->toString for @nodes };

# diag $tree->toString;

