use strict;
use Test::More tests => 8;
use Data::Dumper;
BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  null;

  var a = null;
  if (b == null) {
    alert("uhoh");
  };
};

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree,undef,'Got a parse')
  or diag Dumper($tree);

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//Null');
is(scalar @nodes, 3, "3 null literals found")
  or do { diag $_->toString for @nodes };

@nodes = $tree->findnodes('//VariableDeclaration[./Identifier/text() = "a" and ./Initializer//Null/text() = "null"]');
is(scalar @nodes, 1, "a is assigned null")
  or do { diag $_->toString for @nodes };

@nodes = $tree->findnodes('//EqualityExpression[./*[@name="lhs"]/text() = "b" and ./*[@name="rhs"]//text() = "null"]');
is(scalar @nodes, 1, "b is compared to null")
  or do { diag $_->toString for $tree->findnodes('//EqualityExpression[./*[@name="lhs"]/text() = "b"]') };

# diag $tree->toString;

