use strict;
use Test::More;
use Data::Dumper;
use Carp qw(croak);
use lib 't';
use testlib;

$Data::Dumper::Indent = 1;

my @tests = cases( <<'=cut' );

=head2 Constant new expression

  var a = new 1;

=head2 Constant new expression with (variable) name

  var b = new foo;

=head2 Constant new expression without assignment

  new foo;

=head2 Constant new expression without assignment (camelCased)

  new TestClass;

=head2 Constant new expression as object member without assignment (camelCased)

  new Ajax.Updater;

=cut

plan tests => int (@tests / 3*5) + 1;

use_ok('Javascript::PurePerl');
while (my($todo,$name,$JS) = splice @tests, 0, 3) {
    chomp $name;
    my ($parser,$tree);
    TODO: {
        local $TODO = $todo;
        eval {
            $parser = Javascript::PurePerl->new();
            $tree = $parser->parse( code => $JS,
                  #yydebug => 0x1F,
	    );
        };
        is($@,"","No crash parsing $name")
	    or diag "Code: >>$JS<<";
        SKIP: {
            isn't($tree, undef, "$name was parsed successfully")
                or skip "Unsuccessful parse", 3;
    
            my @nodes = $tree->findnodes('/AST');
            is(scalar @nodes, 1, "AST constructed correctly");

            @nodes = $tree->findnodes('/AST/Program');
            is(scalar @nodes, 1, "Program is top level node");
    
            @nodes = $tree->findnodes('//NewExpression');
            is(scalar @nodes, 1, "1 'new' expression found")
                or do { diag Dumper \@nodes; diag $tree->toString; diag $JS };
        }
    }
};

