use strict;
use Test::More tests => 9;
use Data::Dumper;
use Carp qw(croak);

$Data::Dumper::Indent = 1;

BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  var a = { };
  var b = { foo   : bar };
  var c = {   1   : 2+2 };
  var d = { 'baz' : f() };
  var e = { "baz" : 3 , "bar" : 4 };
};

=for later

=cut

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree, undef, 'JS was parsed successfully');

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//ObjectLiteral');
is(scalar @nodes, 5, "5 object literals found")
  or do { diag $_->toString for $tree->findnodes('//ObjectLiteral'); };

@nodes = $tree->findnodes('//VariableDeclaration[./Identifier/text() = "b"]
                             /Initializer/ObjectLiteral//PropertyPair[./Identifier/text() = "bar" and ./PropertyName/Identifier/text() = "foo"]');
is(scalar @nodes, 1, "b = { foo : bar } found")
  or do { diag $_->toString for $tree->findnodes('//VariableDeclaration[./Identifier/text() = "b"]'); };

@nodes = $tree->findnodes('//VariableDeclaration[./Identifier/text() = "c"]
                             /Initializer/ObjectLiteral//PropertyPair[./AdditiveExpression and ./PropertyName/Number/text() = "1"]');
is(scalar @nodes, 1, "c = { 1 : 2+2 } found")
  or do {
          diag $_->toString for $tree->findnodes('//VariableDeclaration[./Identifier/text() = "c"]');
        };

@nodes = $tree->findnodes('//VariableDeclaration[./Identifier/text() = "d"]
                             /Initializer/ObjectLiteral//PropertyPair[./CallMemberArgs and ./PropertyName/String/text() = "baz"]');
is(scalar @nodes, 1, "d = { 'baz' : f() } found")
  or do { # diag $tree->toString ;
          diag $_->toString for $tree->findnodes('//VariableDeclaration[./Identifier/text() = "d"]');
        };


