use strict;
use Test::More tests => 13;
use Data::Dumper;
BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  if (1) { alert('true'); } else alert("false");

  if (2) alert('true'); else alert('false');

  if (3 == 4) alert('true'); else alert('false');

  if (5) alert('true'); if (6) alert('true'); else alert('false');

  if (7)
    if (8)
      alert('true2');
    else alert('false2');
  else alert('false');

  if (9) { alert('only true branch'); };
};

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree,undef,'Got a parse');

my @nodes;

@nodes = $tree->findnodes('//IfStatement');
is(scalar @nodes, 8, "8 if statements found")
  or do { diag $_->toString for $tree->findnodes('//IfStatement' ) };

@nodes = $tree->findnodes('//IfStatement[.//Number/text() = 1]');
is(scalar @nodes, 1, "1 if statements with expresssion '1' found")
  or do { diag $_->toString for $tree->findnodes('//IfStatement' ) };

@nodes = $tree->findnodes('//IfStatement[.//Number/text() = 1][./Statement[@name = "true"] and ./Statement[@name = "false"]]');
is(scalar @nodes, 1, "True branch and false branch found")
  or do { diag $_->toString for $tree->findnodes('//IfStatement' ) };

@nodes = $tree->findnodes('//IfStatement
                              [.//Number/text() = 1]
                             /Statement
                               [@name = "true"]
                               [ ./Block//CallMemberArgs 
                                 [ ./Identifier[@name="Callee"]="alert" 
                                   and 
                                   ./ArgumentList/String/text() = "true"
                                 ]
                               ]');
is(scalar @nodes, 1, qq{True branch contains 'alert("true");'})
  or do { diag $_->toString for $tree->findnodes('//IfStatement[.//Number/text() = 1]/Statement' ) };

@nodes = $tree->findnodes('//IfStatement[.//Number/text() = 5]');
is(scalar @nodes, 1, "1 if statements with expresssion '5' found")
  or do { diag $_->toString for $tree->findnodes('//IfStatement' ) };

@nodes = $tree->findnodes('//IfStatement[.//Number/text() = 6]');
is(scalar @nodes, 1, "1 if statements with expresssion '6' found")
  or do { diag $_->toString for $tree->findnodes('//IfStatement' ) };

@nodes = $tree->findnodes('//IfStatement[.//IfStatement]');
is(scalar @nodes, 1, "1 nested if statement found")
  or do { diag $_->toString for $tree->findnodes('//IfStatement' ) };
  
@nodes = $tree->findnodes('//IfStatement[.//Number/text() = 9]');
is(scalar @nodes, 1, "1 if statement with expresssion '9' found")
  or do { diag $_->toString for $tree->findnodes('//IfStatement' ) };

@nodes = $tree->findnodes('//IfStatement[.//Number/text() = 9][./Statement[@name = "true"] and not( ./Statement[@name = "false"] )]');
is(scalar @nodes, 1, "Only true branch found")
  or do { diag $_->toString for $tree->findnodes('//IfStatement[.//Number/text() = 9]' ) };

@nodes = $tree->findnodes('//IfStatement
                              [.//Number/text() = 9]
                             /Statement
                               [@name = "true"]
                               [ ./Block//CallMemberArgs 
                                 [ ./Identifier[@name="Callee"]="alert" 
                                   and 
                                   ./ArgumentList/String/text() = "only true branch"
                                 ]
                               ]');
is(scalar @nodes, 1, qq{True branch contains 'alert("only true branch");'})
  or do { diag $_->toString for $tree->findnodes('//IfStatement[.//Number/text() = 9]/Statement' ) };


