use strict;
use Test::More tests => 12;
use Data::Dumper;
BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  'Hello World';
  "Hello World";
  'Hello "World"';
  "'Hello' World";
  'Hello \'World\'';
  "Hello \"World\"";
  "Hello \\\\World\\\\";
};

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree,undef,'Got a parse')
  or diag Dumper($tree);
  
my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//String');
is(scalar @nodes, 7, "7 string literals found")
  or do { diag Dumper \@nodes; diag $tree->toString };

my %values;

$JS =~ s/^\s*//;
$JS =~ s/\s*$//;
for my $string (split /;\s*/sm, $JS) {
  chop $string;
  $string = substr $string, 1;
  $values{$string}++
};

for my $value (sort keys %values) {
  my $expr;
  if ($value =~ /"/) {
    $expr = qq{'$value'}
  } elsif ($value =~ /'/) {
    $expr = qq{"$value"};
  } else {
    $expr = $value;
    $expr =~ s/'/&quot;/g;
    $expr = qq{'$expr'};
  };
  @nodes = $tree->findnodes("//String[text() = $expr]");
  is(scalar @nodes, $values{$value}, "$values{$value} string literal(s) >>$value<< found")
    or do { diag $tree->toString; diag $expr; };
};
